@@ -40,13 +40,17 @@ def lemmatization_text(text):
     result = []
     for word in words:
         r = lemmatizer.lemmatize(word)
-        r = wordnet.morphy(r)
+        r = wordnet.morphy(r) if wordnet.morphy(r) else r
         result.append(r)
     return " ".join(result)
 
 
 def clean_text(raw, clean_punc=True, clean_non_alphabetical=True, clean_stopwords=True,
                lemmatization=True, return_as_string=False):
+    if not nltk.data.find('stopwords'):
+        nltk.download('stopwords')
+    if not nltk.data.find('wordnet'):
+        nltk.download('wordnet')
     result = raw.lower()
     if clean_punc:
         result = clean_punctuation(result)
